@@ -25,7 +25,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: combroyden2.c 1574 2009-08-29 14:07:28Z beerli $
+$Id: combroyden2.c 1854 2011-03-24 18:07:30Z beerli $
  
 -------------------------------------------------------*/
 
@@ -35,17 +35,11 @@ $Id: combroyden2.c 1574 2009-08-29 14:07:28Z beerli $
 #include "joint-chains.h"
 #include "world.h"
 #include "integrate.h"
-#ifndef LAGUERRE
-//#include "derivatives.h"
-//#include "derivatives2.h"
-#endif
 #include "migrate_mpi.h"
 #include "reporter.h"
 #include "tools.h"
-#ifdef LAGUERRE
 #include "laguerre.h"
 #include "gammalike.h"
-#endif
 #ifdef DMALLOC_FUNC_CHECK
 #include <dmalloc.h>
 #endif
@@ -402,11 +396,11 @@ phi (MYREAL t, helper_fmt *b)
   beta = nr->oparam[0] / alpha;
   set_gamma_param (nr->param, nr->oparam, nr->lparam, nr->olparam, t, nr);
   ll = calc_locus_like (nr, nr->param, nr->lparam, locus);
-#ifdef LAGUERRE
+//#ifdef LAGUERRE
   ll = -t / beta + (alpha - 1.) * LOG (t) + ll  + weight;
-#else
-  ll = EXP (-t / beta + (alpha - 1.) * LOG (t) + ll  + weight);
-#endif
+//#else
+//  ll = EXP (-t / beta + (alpha - 1.) * LOG (t) + ll  + weight);
+//#endif
   return ll;
 }
  
@@ -517,13 +511,13 @@ slow_net_combine_gradient (nr_fmt * nr, helper_fmt * helper, MYREAL *gxv)
         }
         else
         {
-#ifdef LAGUERRE
+	  //#ifdef LAGUERRE
             gamma_loci_derivative (helper);
             memcpy (gxv, nr->d, sizeof (MYREAL) * nr->partsize);
-#else
-
-            dt (gxv, helper);
-#endif
+	    //#else
+	    //
+            //dt (gxv, helper);
+	    //#endif
 
             force_symmetric_d (gxv, nr->world->options->migration_model,
                                nr, nnn);
@@ -691,14 +685,14 @@ calc_loci_param (nr_fmt * nr, MYREAL *lparam, MYREAL *olparam, MYREAL *dv,
     }
     else
     {
-        for (i = 0, ii = 0; i < nr->partsize - nr->profilenum; i++)
+        for (i = 0; i < nr->partsize - nr->profilenum; i++)
         {
             ii = nr->indeks[z++];
             lparam[ii] = (MAX (-30., MIN (olparam[ii] - lamda * dv[i], 30.)));
         }
     }
     param_all_adjust (lparam, nr);
-#ifdef LAGUERRE
+    //#ifdef LAGUERRE
 
     if (nr->world->locus >= nr->world->loci && nr->world->options->gamma)
     {
@@ -710,7 +704,7 @@ calc_loci_param (nr_fmt * nr, MYREAL *lparam, MYREAL *olparam, MYREAL *dv,
                       nr->rate, nr->probcat);
         //}
     }
-#endif
+    //#endif
 
 }
 
@@ -1069,7 +1063,7 @@ correct_values (world_fmt * world, nr_fmt * nr)
         }
     }
     z = 0;
-    for (i = 0, ii = 0; i < elem - nr->profilenum; i++)
+    for (i = 0; i < elem - nr->profilenum; i++)
     {
         ii = (nr->profilenum > 0) ? nr->indeks[z++] : i;
         if (world->param0[ii] >= BIGGEST_MIGRATION)
@@ -1349,8 +1343,8 @@ maximize (MYREAL **thisparam, world_fmt * world, nr_fmt * nr, MYREAL **hess, lon
   MYREAL *xv;
   MYREAL *expxv;
   MYREAL *temp;
-  MYREAL *tempparam;  //just pointer into temp
-  MYREAL *templparam;  //just pointer into temp
+  //MYREAL *tempparam;  //just pointer into temp
+  //MYREAL *templparam;  //just pointer into temp
   helper_fmt helper;
   
   setdoublevec1d (&param, *thisparam, nnn);
@@ -1364,8 +1358,8 @@ maximize (MYREAL **thisparam, world_fmt * world, nr_fmt * nr, MYREAL **hess, lon
   doublevec1d (&gama, nnn);
   doublevec1d (&xv, nnn + 1);
   doublevec1d (&temp, 2 * (nnn + 1));
-  tempparam = temp;
-  templparam = temp + nnn + 1;
+ //xcode tempparam = temp;
+ //xcode templparam = temp + nnn + 1;
   helper.xv = xv;
   //  expxv = xv + nnn;
   //memcpy(expxv,param,sizeof(MYREAL)*nnn);
@@ -1439,7 +1433,7 @@ maximize (MYREAL **thisparam, world_fmt * world, nr_fmt * nr, MYREAL **hess, lon
             lamda /= two;
         }
         nr->normd = normd = norm (gxv, nnn);
-#ifdef LAGUERRE
+	//#ifdef LAGUERRE
 
         if (nr->world->locus >= nr->world->loci && nr->world->options->gamma)
         {
@@ -1448,7 +1442,7 @@ maximize (MYREAL **thisparam, world_fmt * world, nr_fmt * nr, MYREAL **hess, lon
             if (fabs (oldL - newL) < 1e-9)
                 lamda = 0.;
         }
-#endif
+	//#endif
         if (world->options->verbose && newL > oldL)
             {
 	      if(helper.boolgamma)
@@ -1678,7 +1672,8 @@ fill_helper (helper_fmt * helper, MYREAL *param, MYREAL *lparam,
 
 void expected_param(MYREAL *param, world_fmt *world)
 {
-    long i, j, tree;
+    long i, tree;
+    //long j;
     tarchive_fmt *thistree;
     long T = world->atl[world->replicate][world->locus].T;
     memset(param,0,sizeof(MYREAL) * world->numpop2);
@@ -1688,7 +1683,8 @@ void expected_param(MYREAL *param, world_fmt *world)
         for(i=0;i<world->numpop; i++)
           {
             param[i] += thistree->kt[i] / 2.;
-            for(j=world->mstart[i];i<world->mend[i]; i++)
+//xcode   j or i?         for(j=world->mstart[i];i<world->mend[i]; i++)
+             for(i=world->mstart[i];i<world->mend[i]; i++)
                 param[i] += 1./thistree->km[i];
           }
       }
