@@ -19,17 +19,12 @@ Copyright 2002 Peter Beerli and Joseph Felsenstein
 Copyright 2003-2008 Peter Beerli
 Copyright 2009-2010 Peter Beerli and Michal Palczewski
  
-$Id: definitions.h 1862 2011-04-07 13:18:47Z beerli $
+$Id: definitions.h 1939 2011-07-17 00:48:55Z beerli $
  
   *----------------------------------------------------------------
   */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "3.2.9"
-#else
-#ifdef SGI
-#undef MIGRATEVERSION
-#define MIGRATEVERSION "3.2.9"
-#endif
+#define MIGRATEVERSION "3.2.16"
 #endif
 #ifndef MIGRATESUBVERSION
 #define MIGRATESUBVERSION "x"
@@ -266,6 +261,7 @@ typedef int boolean;
 /* the first population is the panel for snps*/
 #define PANEL 0
 #define SEQUENCETYPES "snufh" /*s=sequence,n=linked snp, u=unlinked snp, f=ancestral reconstruction h=hapmap snps*/
+#define DNASEQUENCETYPES "sf" /*s=sequence, f=ancestral reconstruction*/
 #define SNPTYPES      "nuh"
 #define ALLELETYPES   "amb" /*a=infinite allele,m=stepwise, b=brownian */
 
@@ -316,11 +312,11 @@ typedef int boolean;
    MUST really be bigger than the number of 
    observed alleles, much bigger does not harm */
 #define MAXALLELES            93L
+#define WORDSIZE 50
 #define SMALLBUFSIZE    255L
 #define ONEMEGABYTE   1024000
 #define MAXBUFSIZE  10000000L
-//#define LINESIZE        1024L /* setting this smaller can break */
-#define LINESIZE      100000L /* setting this smaller can break */
+#define LINESIZE        1024L /* setting this smaller can break */
 #define LONGLINESIZE  100000L /* setting this smaller can break */
 #define SUPERLINESIZE 100000L /*used to read many many loci-sites and indiv numbers*/ 
 #define STRSIZE              255L /* setting this smaller can break */
@@ -334,6 +330,9 @@ typedef int boolean;
 /* don't change below here ------------------------------------
    some other constants */
 /* numerical borders and epsilons*/
+#ifndef __FLT_MAX__
+#define __FLT_MAX__ 3.4028234e+38F
+#endif
 #ifndef HUGE
 #define HUGE 1e200
 #endif 
