@@ -18,7 +18,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: fst.c 1348 2008-09-11 14:42:13Z beerli $
+$Id: fst.c 1807 2011-03-18 20:16:19Z beerli $
  
 -------------------------------------------------------*/
 /*! \file fst.c
@@ -75,7 +75,7 @@ calc_fst (world_fmt * world, data_fmt * data)
 {
     long pop, locus;
     long connections = world->numpop * (world->numpop - 1) / 2;
-    MYREAL ***fstfreq = NULL,  *fw, *fb, *sumfb, *sumfw;
+    MYREAL ***fstfreq,  *fw, *fb, *sumfb, *sumfw;
     if (connections == 0)
         return;
     fw = (MYREAL *) mycalloc (1, sizeof (MYREAL) * world->numpop);
@@ -86,18 +86,21 @@ calc_fst (world_fmt * world, data_fmt * data)
     {
         fst_type ('S');
     }
+ 
+    fstfreq = (MYREAL ***) mycalloc (world->numpop, sizeof (MYREAL **));
+    for (pop = 0; pop < world->numpop; pop++)
+    {
+        doublevec2d(&fstfreq[pop],world->loci,255);  
+        //fstfreq[pop] =
+        //     (MYREAL **) mycalloc (world->loci, sizeof (MYREAL *));
+        //for (locus = 0; locus < world->loci; locus++)
+        //   fstfreq[pop][locus] =
+        //      (MYREAL *) mycalloc (255, sizeof (MYREAL));
+    }
+
     if (!strchr (SEQUENCETYPES, world->options->datatype))
     {
-        fstfreq = (MYREAL ***) mycalloc (1, sizeof (MYREAL **) * world->numpop);
-        for (pop = 0; pop < world->numpop; pop++)
-        {
-            fstfreq[pop] =
-                (MYREAL **) mycalloc (1, sizeof (MYREAL *) * world->loci);
-            for (locus = 0; locus < world->loci; locus++)
-                fstfreq[pop][locus] =
-                    (MYREAL *) mycalloc (1, sizeof (MYREAL) * 255);
-        }
-        frequencies (fstfreq, data->yy, world->numpop, data->numind,
+         frequencies (fstfreq, data->yy, world->numpop, data->numind,
                      world->loci);
     }
     for (locus = 0; locus < world->loci; locus++)
@@ -136,14 +139,16 @@ calc_fst (world_fmt * world, data_fmt * data)
       (*solveNm) (sumfw, sumfb, world->numpop, world->fstparam[world->loci]);
     if (!strchr (SEQUENCETYPES, world->options->datatype))
     {
-        for (pop = 0; pop < world->numpop; pop++)
+      for (pop = world->numpop; pop >= 0; pop++)
         {
-            for (locus = 0; locus < world->loci; locus++)
-                myfree(fstfreq[pop][locus]);
-            myfree(fstfreq[pop]);
+          free_doublevec2d(fstfreq[pop]);
+//          for (locus = world->loci-1; locus >= 0; locus--)
+  //              myfree(fstfreq[pop][locus]);
+    //        myfree(fstfreq[pop]);
         }
-        myfree(fstfreq);
     }
+    myfree(fstfreq);
+
     myfree(fw);
     myfree(fb);
     myfree(sumfw);
