@@ -11,7 +11,7 @@ This software is distributed free of charge for non-commercial use
 and is copyrighted. Of course, we do not guarantee that the software
 works and are not responsible for any damage you may cause or have.
  
-$Id: heating.c 1701 2010-06-13 21:00:45Z beerli $
+$Id: heating.c 1800 2011-01-29 13:40:00Z beerli $
  
 */
 /*! \file heating.c 
@@ -426,11 +426,11 @@ void reset_weight(world_fmt *world)
   seqmodel_fmt *seq = world->data->seq[0]; 
   long endsite = seq->endsite;
   long heated_end = endsite - endsite * 1./world->heat;
-  MYREAL v;
+  //MYREAL v;
   memcpy(seq->aliasweight, seq->savealiasweight, sizeof(long)*endsite);
   for(i=0;i<heated_end; i++)
     {
-      v = RANDINT(0,endsite); 
+    //xcode   v = RANDINT(0,endsite); 
       seq->aliasweight[0] = 0 ;
     }
 }
