@@ -26,7 +26,7 @@ void read_from_bayesmdim_minimal_info(FILE *mdimfile, world_fmt *world,option_fm
 #endif
 {
   char *input;
-  long nrep;
+  //long nrep;
   long pop;
   long tmp;
   boolean done=FALSE;
@@ -74,9 +74,9 @@ void read_from_bayesmdim_minimal_info(FILE *mdimfile, world_fmt *world,option_fm
 	  // fill some more...
 	  data->numpop = world->numpop;
 	  options->newpops_numpop = world->numpop;
-	  nrep = options->replicatenum;
-	  if (nrep == 0)
-	    nrep = 1;
+	//xcode   nrep = options->replicatenum;
+	//xcode   if (nrep == 0)
+	//xcode     nrep = 1;
 	  options->replicate = (boolean) tmp;
 	  if(options->usem != recordedusem)
 	    options->recordedusem = recordedusem;
@@ -153,19 +153,19 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
   long numpop2 = world->numpop2;
   long frompop;
   long topop;
-  long replicate;
-  long T ; // was world->treetimes->T, but this construct is freed, we do not need to
+ // long replicate;
+ // long T ; // was world->treetimes->T, but this construct is freed, we do not need to
   // keep this values as it only used for the output into bayesallfile
-  MYREAL treelength;
+ // MYREAL treelength;
   MYREAL post;
   MYREAL like;
-  MYREAL probg;
-  MYREAL prior;
+//  MYREAL probg;
+//  MYREAL prior;
   MYREAL *params;
 #ifdef BFDEBUG
   long nnn=0;
   long t;
-  MYREAL lsum;
+//  MYREAL lsum;
   long hc = world->options->heated_chains; 
 #endif
   char *input;
@@ -223,13 +223,18 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
 	  locus      = atol(strsep(&inptr,"\t"))-1;
 	  if(locus == -1)
 	    error("help");
-	  replicate  = atol(strsep(&inptr,"\t"))-1;
+	//  replicate  = atol(strsep(&inptr,"\t"))-1;
+      (void) strsep(&inptr,"\t");
 	  post       = atof(strsep(&inptr,"\t"));
 	  like       = atof(strsep(&inptr,"\t"));
-	  probg      = atof( strsep(&inptr,"\t"));
-	  prior      = atof( strsep(&inptr,"\t"));
-	  T = atol(strsep(&inptr,"\t"))+1;
-	  treelength = atof(strsep(&inptr,"\t"));
+	//  probg      = atof( strsep(&inptr,"\t"));
+       (void) strsep(&inptr,"\t");
+	//  prior      = atof( strsep(&inptr,"\t"));
+       (void) strsep(&inptr,"\t");
+	//  T = atol(strsep(&inptr,"\t"))+1;
+       (void) strsep(&inptr,"\t");
+	//  treelength = atof(strsep(&inptr,"\t"));
+       (void) strsep(&inptr,"\t");
 	  params[0] = post;
 	  params[1] = like;
 
@@ -305,7 +310,8 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
 		  world->bf[locus * hc + t] = atof(strsep(&inptr,"\t"));
 		}
 	      // dummy read of thermo sum up to this point
-	      lsum = atof(strsep(&inptr,"\t"));
+	      //lsum = atof(strsep(&inptr,"\t"));
+          (void ) strsep(&inptr,"\t");
 	      // harmonic mean: scaler contains the log value, hm contains 1.
 	      world->hmscale[locus] = atof(strsep(&inptr,"\t"));
 	      world->hm[locus] = 1.; 
