@@ -26,7 +26,7 @@
 *   works and am not responsible for any damage you may cause or have.
 *
 */
-/* $Id: main.c 1857 2011-03-24 18:24:18Z beerli $*/
+/* $Id: main.c 1924 2011-06-09 22:02:51Z beerli $*/
 
 #include "migration.h"
 #include "sighandler.h"
@@ -290,6 +290,7 @@ boolean  check_parmfile(long argcount, char **arguments, char *parmfilename);
 boolean set_usemenu(boolean usemenu, boolean fromparmfile);
 void check_bayes_options(option_fmt *options);
 void reset_bayesmdimfile(world_fmt *world, option_fmt *options);
+long  calculate_newpop_numpop(option_fmt *options, data_fmt *data);
 
 extern void unset_penalizer_function (boolean inprofiles);
 
@@ -348,6 +349,7 @@ main (int argc, char **argv)
 #ifdef MPI
     // parallel version
     filenum = 0;			//setting up the filename database so that worker node can write back to master
+
     MPI_Init (&argc, &argv);
     comm_world = MPI_COMM_WORLD;
     MPI_Comm_size (comm_world, &numcpu);
@@ -355,7 +357,7 @@ main (int argc, char **argv)
     MPI_Comm_group (comm_world, &world_group);
     server = MASTER;		//server ID
     MPI_Group_excl (world_group, 1, &server, &worker_group);
-
+    fprintf(stdout,"%i> after MPI-INIT\n",myID);
     locidone = 0;
 
 #ifdef SLOWNET
@@ -410,14 +412,14 @@ main (int argc, char **argv)
 	get_menu (options, EARTH, data);
 	check_bayes_options(options);
 #ifdef MPI        
-	MYMPIBARRIER (comm_world);
+	//	MYMPIBARRIER (comm_world);
         broadcast_options_master (options, data);
 #endif
       }
     else
       {
 #ifdef MPI
-	MYMPIBARRIER (comm_world);
+	// MYMPIBARRIER (comm_world);
 	broadcast_options_worker (options);
 #endif
 	options->menu = FALSE;
@@ -655,8 +657,11 @@ main (int argc, char **argv)
 	//
 	// print warnings into the PDF and the outfile
 	//
-	print_stored_warnings(EARTH);
-	pdf_print_stored_warnings(EARTH);
+	if(EARTH->options->bayes_infer)
+	  {
+	    print_stored_warnings(EARTH);
+	    pdf_print_stored_warnings(EARTH);
+	  }
 	//
 	//
 	//
@@ -885,6 +890,17 @@ void alloc_sticksize(option_fmt *options, data_fmt *data)
     }
 }
 
+void set_skiploci(option_fmt *options, data_fmt *data, world_fmt **universe)
+{ 
+  long locus;
+  long i;
+  for(locus=0;locus<data->loci;locus++)
+    {
+      for (i = 0; i < options->heated_chains; i++)
+	universe[i]->data->skiploci[locus] = data->skiploci[locus];
+    }
+}
+
 ///
 /// runs the MCMC sampling 
 void
@@ -983,7 +999,7 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
       print_data_summary (EARTH->outfile, EARTH, options, data);
       print_data (EARTH, options, data);
       print_spectra (EARTH, options, data);
-      
+      set_skiploci(options, data, universe);
       if(options->bayes_infer && myID == MASTER)
 	{
 	  if(options->has_bayesmdimfile)
@@ -1148,7 +1164,7 @@ void 	recalc_skyline_values(world_fmt *world, option_fmt * options, long maxrepl
   long i, j, locus;
   mighistloci_fmt *aa;
   long * eventnum;
-  const float invmax = 1./maxreplicate;
+  const float invmax = (float) (1./maxreplicate);
   if(world->options->mighist && world->options->skyline)
     {
       for(locus=0; locus < world->loci; locus++)
@@ -1278,7 +1294,8 @@ prepare_next_chain (world_fmt ** universe, worldoption_fmt * options,
         if (chain < *chains + *pluschain)
         {
             if (((EARTH->param_like > options->lcepsilon)
-		 || (options->gelman && EARTH->convergence->gelmanmaxRall > GELMAN_MYSTIC_VALUE)) 
+		 //|| (options->gelman && EARTH->convergence->gelmanmaxRall > GELMAN_MYSTIC_VALUE)
+		 ) 
 		&& !(options->replicate && options->replicatenum == 0))
             {
                 (*chains)++;
@@ -1411,6 +1428,9 @@ analyze_olddata (world_fmt * world,
         options->replicatenum = listofthings[4];
         Gmax = listofthings[5];
         data->numpop = world->numpop;
+	options->newpops_numalloc = world->numpop;
+	options->newpops = (long*) mycalloc(options->newpops_numalloc, sizeof(long));
+	calculate_newpop_numpop(options,data);
         data->geo = (MYREAL *) mycalloc (1, sizeof (MYREAL) * world->numpop2);
         data->lgeo = (MYREAL *) mycalloc (1, sizeof (MYREAL) * world->numpop2);
 #ifdef WINDOWS
@@ -1490,10 +1510,9 @@ analyze_olddata (world_fmt * world,
 
 boolean analyze_oldbayesdata(world_fmt *world, option_fmt *options, data_fmt *data, long *outfilepos)
 {
-#ifdef MPI
   long pop;
-#endif
   long locus;
+
   // read data from bayesfile
   world->cold=TRUE;
   // reads some minimal information form the header of the bayesallfile
@@ -1507,8 +1526,12 @@ boolean analyze_oldbayesdata(world_fmt *world, option_fmt *options, data_fmt *da
       alloc_sticksize(options,data);
       options->newpops_numalloc = world->numpop;
       options->newpops = (long*) mycalloc(options->newpops_numalloc, sizeof(long));
+      calculate_newpop_numpop(options,data);
+
+      /*options->newpops_numalloc = world->numpop;
+      options->newpops = (long*) mycalloc(options->newpops_numalloc, sizeof(long));
       for(pop=0;pop<world->numpop;pop++)
-	options->newpops[pop]=pop+1;
+      options->newpops[pop]=pop+1;*/
       init_world (world, data, options);
       read_bayes_fromfile(world->bayesmdimfile, world, options);
     }
@@ -1518,7 +1541,6 @@ boolean analyze_oldbayesdata(world_fmt *world, option_fmt *options, data_fmt *da
   alloc_sticksize(options,data);
   options->newpops_numalloc = world->numpop;
   options->newpops = (long*) mycalloc(options->newpops_numalloc, sizeof(long));
-  long pop;
   for(pop=0;pop<world->numpop;pop++)
     options->newpops[pop]=pop+1;
   init_world (world, data, options);
