@@ -16,7 +16,7 @@
  works and are not responsible for any damage you may cause or have.
  
  
- $Id: sequence.c 1860 2011-04-03 15:17:11Z beerli $
+ $Id: sequence.c 1892 2011-05-26 17:00:58Z beerli $
  
 -------------------------------------------------------*/
 /* \file sequence.c
@@ -75,7 +75,7 @@ void printweights (FILE * outfile, world_fmt * world, option_fmt * options,
                    short inc, long chars, short *weight, char *letters);
 void print_seqfreqs (FILE * outfile, world_fmt * world, option_fmt * options);
 
-void snp_invariants (contribarr invariants, world_fmt *world, long locus, phenotype x1);
+void snp_invariants (contribarr invariants, world_fmt *world, long locus, phenotype x1, MYREAL *scaler);
 
 void makevalues_snp (world_fmt * world, option_fmt * options, data_fmt * data,
                      long locus);
@@ -207,11 +207,11 @@ initfreqs (MYREAL *freqa, MYREAL *freqc, MYREAL *freqg, MYREAL *freqt)
 void
 initcatn (long *categs)
 {    /* initialize category number */
-
+  int retval;
     do
     {
         printf ("Number of categories (1-%d)?\n", MAXCATEGS);
-        scanf ("%ld%*[^\n]", categs);
+        retval = scanf ("%ld%*[^\n]", categs);
         getchar ();
     }
     while (*categs > MAXCATEGS || *categs < 1);
@@ -1324,7 +1324,8 @@ inputcategs (long a, long b, world_fmt * world, option_fmt * options,
     /* input the categories, 1-9 */
     char ch;
     long i;
-	char input[LINESIZE];
+    char input[LINESIZE];
+    int retval;
     ch = getc (data->catfile);
     while (ch == '#')
     {
@@ -1332,15 +1333,15 @@ inputcategs (long a, long b, world_fmt * world, option_fmt * options,
         ch = getc (data->catfile);
     }
     ungetc (ch, data->catfile);
-    fscanf (data->catfile, "%ld", &options->categs);
+    retval = fscanf (data->catfile, "%ld", &options->categs);
     options->rate =
         (MYREAL *) myrealloc (options->rate, sizeof (MYREAL) * options->categs);
     for (i = 0; i < options->categs; i++)
     {
 #ifdef USE_MYREAL_FLOAT
-        fscanf (data->catfile, "%f", &options->rate[i]);
+        retval = fscanf (data->catfile, "%f", &options->rate[i]);
 #else
-        fscanf (data->catfile, "%lf", &options->rate[i]);
+        retval = fscanf (data->catfile, "%lf", &options->rate[i]);
 #endif
     }
 
@@ -1414,14 +1415,15 @@ empiricalfreqs (world_fmt * world, option_fmt * options, seqmodel_fmt * seq,
 void
 initlambda (option_fmt * options)
 {
+  int retval;
     while (options->lambda <= 1.0)
     {
         printf
         ("Mean block length of sites having the same rate\n (needs to be greater than 1)?\n");
 #ifdef USE_MYREAL_FLOAT
-        scanf ("%f%*[^\n]", &options->lambda);
+        retval = scanf ("%f%*[^\n]", &options->lambda);
 #else
-        scanf ("%lf%*[^\n]", &options->lambda);
+        retval = scanf ("%lf%*[^\n]", &options->lambda);
 #endif
         getchar ();
     }
@@ -1705,7 +1707,7 @@ snp_invariants_original (contribarr invariants, long endsite, long rcategs,
 }
 
 void
-snp_invariants (contribarr invariants, world_fmt *world, long locus, phenotype x1)
+snp_invariants (contribarr invariants, world_fmt *world, long locus, phenotype x1, MYREAL *scaler)
 {
     worldoption_fmt *opt;
     seqmodel_fmt *seq =  world->data->seq[0];
@@ -1729,10 +1731,10 @@ snp_invariants (contribarr invariants, world_fmt *world, long locus, phenotype x
 	  {
 	    val = &(x1[i][j]);
             invariants[j] +=
-	      (freqa * (*val)[0] + freqc * (*val)[1] +
-	       freqg * (*val)[2] + freqt * (*val)[3]);
+	      exp(scaler[i]) * ((freqa * (*val)[0] + freqc * (*val)[1] +
+	       freqg * (*val)[2] + freqt * (*val)[3]));
 	  }
-	invariants[j] = 1 - invariants[j];
+	invariants[j] = 1.0 - invariants[j];
       }
     //    printf("invariant0=%f\n",invariants[0]);
 }    /* snp_invariants*/
@@ -1762,7 +1764,7 @@ treelike_snp (world_fmt * world, long locus)
     p = crawlback (world->root->next);
     summ = 0.0;
     /* snp invariants */
-    snp_invariants (invariants,world, locus, p->x.s);
+    snp_invariants (invariants,world, locus, p->x.s, p->scale);
     for (j = 0; j < opt->rcategs; j++)
       {
 	if(invariants[j] <= 0.0)
@@ -1773,54 +1775,67 @@ treelike_snp (world_fmt * world, long locus)
 	    return -MYREAL_MAX;
 	  }
       }
-    for (i = 0; i < seq->endsite - seq->addon; i++)
-    {
-        scale = p->scale[i];
-        for (j = 0; j < opt->rcategs; j++)
-        {
-            x1 = &(p->x.s[i][j]);
-            tterm[j] =
-                (freqa * (*x1)[0] + freqc * (*x1)[1] +
-                 freqg * (*x1)[2] + freqt * (*x1)[3]) /invariants[j];
-        }
-        sumterm = 0.0;
-        for (j = 0; j < opt->rcategs; j++)
-            sumterm += opt->probcat[j] * tterm[j];
-        lterm = LOG (sumterm) + scale;
-        for (j = 0; j < opt->rcategs; j++)
-	  world->contribution[i][j] = tterm[j] / sumterm;
-
-        summ += seq->aliasweight[i] * lterm;
-    }    /* over endsite - 4[snp-invariants] */
-    for (j = 0; j < opt->rcategs; j++)
-        like[j] = 1.0;
-    for (i = 0; i < seq->sites[locus]; i++)
-    {
-        sumc = 0.0;
-        for (k = 0; k < opt->rcategs; k++)
-            sumc += opt->probcat[k] * like[k];
-        sumc *= opt->lambda;
-        if ((seq->ally[i] > 0) && (seq->location[seq->ally[i] - 1] > 0))
-        {
-            lai = seq->location[seq->ally[i] - 1];
-            for (j = 0; j < opt->rcategs; j++)
-                nulike[j] =
+    if(opt->rcategs==1)
+      {
+	for (i = 0; i < seq->endsite - seq->addon; i++)
+	  {
+	    scale = p->scale[i];
+	    x1 = &(p->x.s[i][j]);
+	    tterm[0] = (freqa * (*x1)[0] + freqc * (*x1)[1] + freqg * (*x1)[2] + freqt * (*x1)[3]);
+	    summ += seq->aliasweight[i] * (LOG (tterm[0]) + scale - log(invariants[0]));
+	  }
+	return summ;
+      }
+    else
+      {
+	for (i = 0; i < seq->endsite - seq->addon; i++)
+	  {
+	    scale = p->scale[i];
+	    for (j = 0; j < opt->rcategs; j++)
+	      {
+		x1 = &(p->x.s[i][j]);
+		tterm[j] =
+		  (freqa * (*x1)[0] + freqc * (*x1)[1] +
+		   freqg * (*x1)[2] + freqt * (*x1)[3]) /invariants[j];
+	      }
+	    sumterm = 0.0;
+	    for (j = 0; j < opt->rcategs; j++)
+	      sumterm += opt->probcat[j] * tterm[j];
+	    lterm = LOG (sumterm) + scale;
+	    for (j = 0; j < opt->rcategs; j++)
+	      world->contribution[i][j] = tterm[j] / sumterm;
+	    
+	    summ += seq->aliasweight[i] * lterm;
+	  }    /* over endsite - 4[snp-invariants] */
+	for (j = 0; j < opt->rcategs; j++)
+	  like[j] = 1.0;
+	for (i = 0; i < seq->sites[locus]; i++)
+	  {
+	    sumc = 0.0;
+	    for (k = 0; k < opt->rcategs; k++)
+	      sumc += opt->probcat[k] * like[k];
+	    sumc *= opt->lambda;
+	    if ((seq->ally[i] > 0) && (seq->location[seq->ally[i] - 1] > 0))
+	      {
+		lai = seq->location[seq->ally[i] - 1];
+		for (j = 0; j < opt->rcategs; j++)
+		  nulike[j] =
                     ((1.0 - opt->lambda) * like[j] +
                      sumc) * world->contribution[lai - 1][j];
-        }
-        else
-        {
-            for (j = 0; j < opt->rcategs; j++)
-                nulike[j] = ((1.0 - opt->lambda) * like[j] + sumc);
-        }
-        swap (nulike, like);
-        //memcpy (like, nulike, size);
-    }
-    sum2 = 0.0;
-    for (i = 0; i < opt->rcategs; i++)
-        sum2 += opt->probcat[i] * like[i];
-    summ += LOG (sum2);
-    return summ;
+	      }
+	    else
+	      {
+		for (j = 0; j < opt->rcategs; j++)
+		  nulike[j] = ((1.0 - opt->lambda) * like[j] + sumc);
+	      }
+	    swap (nulike, like);
+	  }
+	sum2 = 0.0;
+	for (i = 0; i < opt->rcategs; i++)
+	  sum2 += opt->probcat[i] * like[i];
+	summ += LOG (sum2);
+	return summ;
+      }
 }    /* treelike_snp */
 
 
@@ -1849,7 +1864,7 @@ treelike_snp_unlinked (world_fmt * world, long locus)
     p = crawlback (world->root->next);
     summ = 0.0;
     /* snp invariants */
-    snp_invariants (invariants, world, locus, p->x.s);
+    snp_invariants (invariants, world, locus, p->x.s, p->scale);
     /* no rate categories used */
     for (i = 0; i < seq->endsite; i++)
     {
