@@ -20,7 +20,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c 1866 2011-04-28 20:03:46Z beerli $
+$Id: tools.c 1927 2011-06-12 04:37:03Z beerli $
 -------------------------------------------------------*/
 /* \file tools.c */
 
@@ -154,6 +154,7 @@ MYREAL chisquare (long df, MYREAL alpha);
 
 MYREAL chiboundary (long zeros, long nonzeros, MYREAL alpha);
 
+extern long  calculate_newpop_numpop(option_fmt *options, data_fmt *data);
 
 #ifdef MESS
 long *check_collection;
@@ -1055,7 +1056,7 @@ long read_word_delim(char *input, char *word, char * delim)
     return 0;
   while (isspace (ch))
     ch = input[i++];
-  while(strchr(delim, ch)==NULL)
+  while(strchr(delim, ch)==NULL && ch!=EOF)
     {
       word[count++] = ch;
       ch = input[i++];
@@ -1066,20 +1067,26 @@ long read_word_delim(char *input, char *word, char * delim)
 ///
 /// read a single word from a file
 /// words are delimited by withespace 
-void read_word(FILE *infile, char *word)
+int read_word(FILE *infile, char *word)
 {
     int ch;
     long count = 0;
     ch = getc(infile);
     while (isspace (ch))
         ch = getc(infile);
-    while(strchr(" \t\n\r", ch)==NULL)
+    while(strchr(" \t\n\r", ch)==NULL && ch!=EOF)
     {
         word[count++] = ch;
         ch = getc(infile);
     }
     word[count]='\0';
-    ungetc(ch,infile);
+    if(ch==EOF)
+      return EOF;
+    else
+      {
+	ungetc(ch,infile);
+	return 0;
+      }
 }
 
 //========================================
@@ -1253,6 +1260,7 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
     long z, zz, jj;
     MYREAL tmpm;
     boolean newstyle = TRUE;
+    int retval;
 #ifdef MPI
 
     long listofthings[6];
@@ -1304,6 +1312,9 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
         memset (data->skiploci, 0, sizeof (boolean) * (data->loci + 1));
         read_geofile (data, options, world->numpop);
         data->numpop = world->numpop;
+	options->newpops_numalloc = world->numpop;
+	options->newpops = (long*) mycalloc(options->newpops_numalloc, sizeof(long));
+	calculate_newpop_numpop(options,data);
         set_plot (options);
 	world->cold=TRUE;
         init_world (world, data, options);
@@ -1312,16 +1323,16 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
             for (r = 0; r < nrep; r++)
             {
                 FGETS (input, 1024, sumfile);
-                fscanf (sumfile, "%li %li %li\n", &ta[r][l].T, &ta[r][l].numpop,
+                retval = fscanf (sumfile, "%li %li %li\n", &ta[r][l].T, &ta[r][l].numpop,
                         &ta[r][l].sumtips);
                 Gmax = (ta[r][l].T > Gmax) ? ta[r][l].T : Gmax;
                 ta[r][l].allocT = 0;
                 increase_timearchive (world, l, ta[r][l].T, world->numpop, r);
 #ifdef USE_MYREAL_FLOAT
-                fscanf (sumfile, "%g %g %g\n", &ta[r][l].param_like,
+                retval = fscanf (sumfile, "%g %g %g\n", &ta[r][l].param_like,
                         &ta[r][l].thb, &ta[r][l].alpha);
 #else
-                fscanf (sumfile, "%lg %lg %lg\n", &ta[r][l].param_like,
+		retval =  fscanf (sumfile, "%lg %lg %lg\n", &ta[r][l].param_like,
                         &ta[r][l].thb, &ta[r][l].alpha);
 #endif
                 world->chainlikes[l][r] = ta[r][l].param_like;
@@ -1329,17 +1340,17 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
                 for (i = 0; i < world->atl[r][l].T; i++)
                 {
 #ifdef USE_MYREAL_FLOAT
-                    fscanf (sumfile, "%li %f\n", &ta[r][l].tl[i].copies, &ta[r][l].tl[i].lcopies);
+                    retval = fscanf (sumfile, "%li %f\n", &ta[r][l].tl[i].copies, &ta[r][l].tl[i].lcopies);
 #else
-                    fscanf (sumfile, "%li %lf\n", &ta[r][l].tl[i].copies, &ta[r][l].tl[i].lcopies);
+                    retval = fscanf (sumfile, "%li %lf\n", &ta[r][l].tl[i].copies, &ta[r][l].tl[i].lcopies);
 #endif
                     for (j = 0; j < world->numpop; j++)
                     {
 #ifdef USE_MYREAL_FLOAT
-                        fscanf (sumfile, "%f %f %f\n", &ta[r][l].tl[i].km[j],
+                        retval = fscanf (sumfile, "%f %f %f\n", &ta[r][l].tl[i].km[j],
                                 &ta[r][l].tl[i].kt[j], &ta[r][l].tl[i].p[j]);
 #else               
-                        fscanf (sumfile, "%lf %lf %lf\n", &ta[r][l].tl[i].km[j],
+                        retval = fscanf (sumfile, "%lf %lf %lf\n", &ta[r][l].tl[i].km[j],
                                 &ta[r][l].tl[i].kt[j], &ta[r][l].tl[i].p[j]);
 #endif
                     }
@@ -1348,9 +1359,9 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
                         for (j = 0; j < world->numpop2; j++)
                         {
 #ifdef USE_MYREAL_FLOAT
-                            fscanf (sumfile, "%f ", &ta[r][l].tl[i].mindex[j]);
+                            retval = fscanf (sumfile, "%f ", &ta[r][l].tl[i].mindex[j]);
 #else
-                            fscanf (sumfile, "%lf ", &ta[r][l].tl[i].mindex[j]);
+                            retval = fscanf (sumfile, "%lf ", &ta[r][l].tl[i].mindex[j]);
 #endif
                         }
                     }
@@ -1363,9 +1374,9 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
                             for (jj = 0; jj < world->numpop; jj++)
                             {
 #ifdef USE_MYREAL_FLOAT
-                                fscanf (sumfile, "%f ", &tmpm);
+                                retval = fscanf (sumfile, "%f ", &tmpm);
 #else
-                                fscanf (sumfile, "%lf ", &tmpm);
+                                retval = fscanf (sumfile, "%lf ", &tmpm);
 #endif
                                 if (j == jj)
                                     ta[r][l].tl[i].mindex[z++] = tmpm;
@@ -1379,10 +1390,10 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
                 for (i = 0; i < world->numpop2; i++)
                 {
 #ifdef USE_MYREAL_FLOAT
-                    fscanf (sumfile, "%g %g\n", &ta[r][l].param[i],
+                    retval = fscanf (sumfile, "%g %g\n", &ta[r][l].param[i],
                             &ta[r][l].param0[i]);
 #else
-                    fscanf (sumfile, "%lg %lg\n", &ta[r][l].param[i],
+                    retval = fscanf (sumfile, "%lg %lg\n", &ta[r][l].param[i],
                             &ta[r][l].param0[i]);
 #endif
                 }
@@ -1393,9 +1404,9 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
                 //  }
                 //      FGETS(input,1024,sumfile);
 #ifdef USE_MYREAL_FLOAT
-                fscanf (sumfile, "%li %g\n", &ta[r][l].trials, &ta[r][l].normd);
+                retval = fscanf (sumfile, "%li %g\n", &ta[r][l].trials, &ta[r][l].normd);
 #else
-                fscanf (sumfile, "%li %lg\n", &ta[r][l].trials, &ta[r][l].normd);
+                retval = fscanf (sumfile, "%li %lg\n", &ta[r][l].trials, &ta[r][l].normd);
 #endif           
             }
     }
@@ -3388,54 +3399,77 @@ void record_warnings(world_fmt * world, const char *fmt, ...)
   long mypos=0;
   char *p = (char *) calloc(LINESIZE,sizeof(char));
   va_list ap;
-  va_start(ap, fmt);
-  mypos = vsprintf(p, fmt, ap);
-  va_end(ap);
-  if((world->warningsize + mypos) < world->warningallocsize)
-      {
-	world->warningsize += sprintf(world->warning + world->warningsize, "%s\n",p);
-      }
-    else
-      {
-	world->warningallocsize = world->warningsize + 4 * mypos; // add some extra space
-	if(world->warning != NULL)
+  if(myID==MASTER && world->cold)
+    {
+      va_start(ap, fmt);
+      mypos = vsprintf(p, fmt, ap);
+      va_end(ap);
+      if((world->warningsize + mypos) < world->warningallocsize)
+	{
+	  world->warningsize += sprintf(world->warning + world->warningsize, "%s\n",p);
+	}
+      else
+	{
+	  world->warningallocsize = world->warningsize + 4 * mypos; // add some extra space
+	  if(world->warning != NULL)
 	    world->warning = (char *) myrealloc (world->warning, world->warningallocsize * sizeof (char));
-	else
-	  world->warning = (char *) mycalloc (world->warningallocsize, sizeof (char));
-	world->warningsize += sprintf(world->warning + world->warningsize, "%s\n",p);
-      }
+	  else
+	    world->warning = (char *) mycalloc (world->warningallocsize, sizeof (char));
+	  world->warningsize += sprintf(world->warning + world->warningsize, "%s\n",p);
+	}
+    }
   myfree(p);
 }
 
+
+
+
 void print_warning2(FILE *file, world_fmt *world)
 {
-      fprintf(file,"\nPOTENTIAL PROBLEMS\n");
-      fprintf(file,"-------------------------------------------------------------------\n");
-      fprintf(file,"This section reports potential problems with your run. Such reporting\n");      
-      fprintf(file,"is tricky. When many parameters in  multilocus analysis\n");      
-      fprintf(file,"are estimated then it is very common that some parameters for some loci\n");      
-      fprintf(file,"will not be very informative, triggering suggestions (for example to\n");
-      fprintf(file,"increase the prior range) that are not sensible. This suggestion tool\n");
-      fprintf(file,"will improve with time. If some parameters are flagged inspect the tables\n");
-      fprintf(file,"carefully and judge wether an action is required. For example if you run\n");
-      fprintf(file,"a Bayesian inference with sequence data, for macroscopic species there is\n");
-      fprintf(file,"rarely the need to increase the prior for Theta beyond 0.1, but if you use\n");
-      fprintf(file,"microsatellites it is rather common that your prior for Theta has a range\n");
-      fprintf(file,"from 0.0 to 100 or more. With many populations (>3) it is also very common\n");      
-      fprintf(file,"that some migration routes are estimated poorly because there is no data.\n");
-      fprintf(file,"Increasing the range will not help in such situations, reducing number of\n");
-      fprintf(file,"parameters may help in such situations.\n\n");
-      fprintf(file,"-------------------------------------------------------------------\n");
-      if (world->warning[0]=='\0')
-	fprintf(file,"No warning was recorded during the run\n\n");
-      else
-	fprintf(file,"%s\n\n", world->warning);
-      fprintf(file,"-------------------------------------------------------------------\n");
-      
+  char paragraph[] = "This section reports potential problems with your run, but such reporting is often not very accurate. Whith many parameters in a multilocus analysi\
+s, it is very common that some parameters for some loci will not be very informative, triggering suggestions (for example to increase the prior ran\
+ge) that are not sensible. This suggestion tool will improve with time, therefore do not blindly follow its suggestions. If some parameters are fla\
+gged, inspect the tables carefully and judge wether an action is required. For example, if you run a Bayesian inference with sequence data, for mac\
+roscopic species there is rarely the need to increase the prior for Theta beyond 0.1; but if you use microsatellites it is rather common that your \
+prior distribution for Theta should have a range from 0.0 to 100 or more. With many populations (>3) it is also very common that some migration rou\
+tes are estimated poorly because the data contains little or no information for that route. Increasing the range will not help in such situations, \
+reducing number of parameters may help in such situations.\0";
+  long i=0;
+  long z=0;
+  char *section;
+  section = (char*) mycalloc(LINESIZE,sizeof(char));
+  fprintf(file,"\nPOTENTIAL PROBLEMS\n");
+  print_line(file,'-',90,10);
+  while (paragraph[i] != '\0')
+    {
+      section[z]=paragraph[i];
+      section[z+1] = '\0';
+      z++;
+      i++;
+      if(z >= 90)
+	{
+	  while(section[z-1]!=' ')
+	    {
+	      z--;
+	      i--;
+	    }
+	  section[z]='\0';
+	  fprintf(file,"%s\n",section);
+	  section[0]='\0';
+	  z=0;
+	}
+    }
+  fprintf(file,"%s\n",section);
+  print_line(file,'-',90,10);
+  if (world->warning[0]=='\0')
+    fprintf(file,"No warning was recorded during the run\n\n");
+  else
+    fprintf(file,"%s", world->warning);
+  print_line(file,'-',90,10);
+  myfree(section);
 }
 
 
-
 void print_stored_warnings(world_fmt *world)
 {
   if(world->warningsize>0)
